@@ -4,6 +4,11 @@ from atomict.api import get, patch
 from atomict.exceptions import UserTaskAbortException
 
 
+class SimulationAction(Enum):
+    SAVE_DRAFT = "DRAFT"
+    LAUNCH = "LAUNCH"
+
+
 class TaskStatus(Enum):
     DRAFT = 0
     READY = 1
@@ -14,22 +19,22 @@ class TaskStatus(Enum):
     USER_ABORTED = 6
 
 
-def get_task(task_uuid: str):
-    return get(f"api/tasks/{task_uuid}/")
+def get_task(task_id: str):
+    return get(f"api/tasks/{task_id}/")
 
 
-def task_should_abort(task_uuid: str) -> bool:
-    task = get_task(task_uuid)
+def task_should_abort(task_id: str) -> bool:
+    task = get_task(task_id)
     return task["user_aborted_flag"]
 
 
-def except_on_user_abort(task_uuid: str):
-    if task_should_abort(task_uuid):
-        raise UserTaskAbortException(f"User aborted task {task_uuid}")
+def except_on_user_abort(task_id: str):
+    if task_should_abort(task_id):
+        raise UserTaskAbortException(f"User aborted task {task_id}")
 
 
 def update_task_status(
-    task_uuid: str, status: TaskStatus = None, error_msg: str = None, percent: int = None, progress_indeterminate: bool = None
+    task_id: str, status: TaskStatus = None, error_msg: str = None, percent: int = None, progress_indeterminate: bool = None
 ):
     payload = {}
 
@@ -45,5 +50,5 @@ def update_task_status(
     if progress_indeterminate is not None:
         payload["progress_indeterminate"] = progress_indeterminate
 
-    res = patch(f"api/tasks/{task_uuid}/", payload=payload)
+    res = patch(f"api/tasks/{task_id}/", payload=payload)
     return res
